Stan Math Library: stan/math/prim/mat/fun/accumulator.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
accumulator.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/sum.hpp>`
`#include <boost/utility/enable_if.hpp>`
`#include <boost/type_traits/is_arithmetic.hpp>`
`#include <boost/type_traits/is_same.hpp>`
`#include <vector>`

Go to the source code of this file.

## Classes
class | stan::math::accumulator< T >
| Class to accumulate values and eventually return their sum. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.